Grid search of sample size is used for guarantee a desirable type I error rate.
The upper limitation is 200, and lower limitation default is sample size 50
for the control and treatment groups at each stage. Default increment of the
sequence is 50.
For the parameter estimation section, we have two options, and can be selected using
the method argument.Two following options are available: (i) method = "Frequentist",
(ii) method = "Bayesian". If method = "Frequentist", parameters are estimated via package
ordinal, which is based on frequentist method, while method = "Bayesian", parameters are
estimated through Bayesian model.
Specifically, the numerical utilities U reflect the desirability of each outcome
level. To do this, in our example, we first set U[1] = 100 and U[5] = 0, and then
asked physicians to specify numerical values for the intermediate levels, that
reflect their desirability relative to the best and worst levels.
Please note, in our example, argument ntrial = 5 is for the time saving purpose.